==> paraview_3.8.0.orig.tar.gz: ParaView-3.8.0/Servers/Filters/vtkPVHardwareSelector.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVHardwareSelector.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPVHardwareSelector - vtkHardwareSelector subclass with logic to work
// in Parallel.
// .SECTION Description
//

#ifndef __vtkPVHardwareSelector_h
#define __vtkPVHardwareSelector_h

#include "vtkHardwareSelector.h"

class VTK_EXPORT vtkPVHardwareSelector : public vtkHardwareSelector
{
public:
  static vtkPVHardwareSelector* New();
  vtkTypeMacro(vtkPVHardwareSelector, vtkHardwareSelector);
  void PrintSelf(ostream& os, vtkIndent indent);

  void BeginSelection()
    { this->Superclass::BeginSelection(); }
  void SetCurrentPass(int pass)
    { this->CurrentPass = pass; }
  void EndSelection()
    { this->Superclass::EndSelection(); }

  vtkSetMacro(NumberOfIDs, vtkIdType);
  vtkGetMacro(NumberOfIDs, vtkIdType);

  vtkSetMacro(NumberOfProcesses, int);
  vtkGetMacro(NumberOfProcesses, int);

//BTX
protected:
  vtkPVHardwareSelector();
  ~vtkPVHardwareSelector();

  // Description:
  // Return a unique ID for the prop.
  virtual int GetPropID(int idx, vtkProp* prop);

  // Description:
  // Returns is the pass indicated is needed.
  virtual bool PassRequired(int pass);

  int NumberOfProcesses;
  vtkIdType NumberOfIDs;
private:
  vtkPVHardwareSelector(const vtkPVHardwareSelector&); // Not implemented
  void operator=(const vtkPVHardwareSelector&); // Not implemented
//ETX
};

#endif

==> paraview_3.10.1.orig.tar.gz: ParaView-3.10.1/Servers/Filters/vtkPVHardwareSelector.h <==
/*=========================================================================

  Program:   ParaView
  Module:    vtkPVHardwareSelector.h

  Copyright (c) Kitware, Inc.
  All rights reserved.
  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkPVHardwareSelector - vtkHardwareSelector subclass with paraview
// sepecific logic to avoid recapturing buffers unless needed.
// .SECTION Description
// vtkHardwareSelector is subclass of vtkHardwareSelector that adds logic to
// reuse the captured buffers as much as possible. Thus avoiding repeated
// selection-rendering of repeated selections or picking.

#ifndef __vtkPVHardwareSelector_h
#define __vtkPVHardwareSelector_h

#include "vtkHardwareSelector.h"

class VTK_EXPORT vtkPVHardwareSelector : public vtkHardwareSelector
{
public:
  static vtkPVHardwareSelector* New();
  vtkTypeMacro(vtkPVHardwareSelector, vtkHardwareSelector);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Overridden to avoid clearing of captured buffers.
  vtkSelection* Select(int region[4]);

  // Description:
  // Returns true when the next call to Select() will result in renders to
  // capture the selection-buffers.
  virtual bool NeedToRenderForSelection();

//BTX
protected:
  vtkPVHardwareSelector();
  ~vtkPVHardwareSelector();

  vtkTimeStamp CaptureTime;
private:
  vtkPVHardwareSelector(const vtkPVHardwareSelector&); // Not implemented
  void operator=(const vtkPVHardwareSelector&); // Not implemented
//ETX
};

#endif
